@@ -162,7 +162,7 @@ void Controller::getMediaPlayerFromDB() {
         while (query.next()) {
             player = query.value(0).toString();
         }
-        //        qDebug() << player;
+                qDebug() << player;
     }
     if (player == "cuteTube Player") {
         player = "Media Player";
@@ -227,7 +227,6 @@ QStringList Controller::getInstalledMediaPlayers() const {
 void Controller::playVideo(const QString &url) {
     //    qDebug() << url;
 #ifdef Q_WS_MAEMO_5
-    minimize();
     if (mediaPlayer == "mplayer") {
         QStringList args;
         args << "-cache" << "4096" << "-fs" << url;
@@ -242,7 +241,7 @@ void Controller::playVideo(const QString &url) {
     }
 #else
     if (url.startsWith("http://")) {
-        QFile ytlink("E:/Videos/cutetube/cutetube.ram");
+        QFile ytlink("/home/stuart/N900/cutetube.ram");
         ytlink.open(QIODevice::WriteOnly);
         ytlink.write(url.toAscii());
         ytlink.close();
