@@ -1,10 +1,16 @@
 function getDailymotionSearch(query, order) {
     var searchOrders = { "rating": "rated", "published": "recent", "viewCount": "visited-today", "relevance": "relevance" };
     order = searchOrders[order];
-    var encodedQuery = encodeURIComponent(query.replace(/\s.\s/gi, " "));
     var safe = (Settings.getSetting("safeSearch") == "none") ? "false" : "true";
     var videoFeed = "https://api.dailymotion.com/videos?limit=50&family_filter=" + safe + "&fields="
-        + _DM_FIELDS + "&sort=" + order + "&search=" + encodedQuery.replace(/\s/g, "+");
+        + _DM_FIELDS + "&sort=" + order;
+    if (query.slice(0, 6) == "group=") {
+        videoFeed += "&" + query;
+    }
+    else {
+       var encodedQuery = encodeURIComponent(query.replace(/\s.\s/gi, " "));
+       videoFeed += "&search=" + encodedQuery.replace(/\s/g, "+");
+    }
     return videoFeed;
 }
 
@@ -28,9 +34,8 @@ function getDailymotionVideos() {
                                           "largeThumbnail": res.thumbnail_large_url, "dailymotion": true });
                 }
             }
-
-            videoListModel.loading = false;
             videoListModel.page++;
+            videoListModel.loading = false;
         }
     }
     doc.open("GET", videoFeed + "&page=" + videoListModel.page.toString());
@@ -57,9 +62,8 @@ function getRelatedVideos() {
                                     "thumbnail": res.thumbnail_medium_url,
                                     "largeThumbnail": res.thumbnail_large_url, "dailymotion": true });
             }
-
-            relatedModel.loading = false;
             relatedModel.page++;
+            relatedModel.loading = false;
         }
     }
     doc.open("GET", relatedView.videoFeed + "&page=" + relatedModel.page.toString());
