@@ -127,7 +127,7 @@ function loadVideos(feeds, title, site) {
     loader.item.goToVimeoVideo.connect(loadVimeoVideoInfo);
     loader.item.playVideos.connect(loadPlaybackView);
     if (!site) {
-        site = _DEFAULT_SITE;
+        site = __defaultSite;
     }
     loader.item.setVideoFeeds(feeds, site);
     notificationArea.addTitle(title);
@@ -315,7 +315,7 @@ function loadPlaybackView(videoList) {
         loader.source = "VideoPlaybackView.qml";
         notificationArea.addTitle(qsTr("Playback View"));
         toggleControls(false);
-        _VIDEO_PLAYING = true;
+        __videoPlaying = true;
         loader.item.setPlaylist(videoList);
         windowView.incrementCurrentIndex();
         loader.item.playbackStopped.connect(stopPlaying);
@@ -345,7 +345,7 @@ function loadPlaybackView(videoList) {
 
 function stopPlaying() {
     toggleControls(true);
-    _VIDEO_PLAYING = false;
+    __videoPlaying = false;
     Controller.setOrientation(Settings.getSetting("screenOrientation"));
     Controller.doNotDisturb(false);
     goToPreviousView();
