@@ -189,8 +189,7 @@ function getAllAccounts(site) {
 function setDefaultSettings() {
     /* Set defaults if no settings exist */
 
-    var settings = [ [ "playbackQuality", "hq" ],
-                    [ "downloadQuality", "hq" ],
+    var settings = [ [ "downloadQuality", "hq" ],
                     [ "downloadStatus", "queued" ],
                     [ "downloadPath", Controller.isSymbian ? "E:/Videos/" : "/home/user/MyDocs/.cutetube/" ],
                     [ "categoryFeedOne", "MostRecent"],
