@@ -40,8 +40,8 @@ function getYouTubeVideos() {
                     }
                 }
             }
+            videoListModel.page++;
             videoListModel.loading = false;
-            videoListModel.page++
         }
     }
     doc.open("GET", videoFeed + "&start-index=" + (videoListModel.page * 50 + 1).toString());
@@ -106,8 +106,8 @@ function getComments(videoId) {
                                             "commentId": res.id.$t });
                 }
             }
+            commentsModel.page++;
             commentsModel.loading = false;
-            commentsModel.page++
         }        
     }
     doc.open("GET", "http://gdata.youtube.com/feeds/api/videos/" + videoId + "/comments?v=2&max-results=50&alt=json&start-index=" + (commentsModel.page * 50 + 1).toString());
@@ -136,8 +136,8 @@ function getSubscriptions() {
                                             "subscriptionId": res.id.$t });
                 }
             }
+            subscriptionsModel.page++;
             subscriptionsModel.loading = false;
-            subscriptionsModel.page++
         }
     }
     doc.open("GET", _SUBSCRIPTIONS_FEED + "&start-index=" + (subscriptionsModel.page * 50 + 1).toString());
@@ -171,8 +171,8 @@ function getPlaylists() {
                                             "description": res.summary.$t });
                 }
             }
+            playlistModel.page++;
             playlistModel.loading = false;
-            playlistModel.page++
         }        
     }
     doc.open("GET", _PLAYLISTS_FEED + "&start-index=" + (playlistModel.page * 50 + 1).toString());
